
From: David Teigland <teigland@redhat.com>

Consistently handle the declarations of ifdef'ed debug functions in the
two places they occur.

Signed-off-by: David Teigland <teigland@redhat.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/dlm/dlm_internal.h |    8 --------
 drivers/dlm/lockspace.c    |    8 ++++++++
 2 files changed, 8 insertions(+), 8 deletions(-)

diff -puN drivers/dlm/dlm_internal.h~dlm-lockspaces-callbacks-directory-dlm-consistent-ifdefs drivers/dlm/dlm_internal.h
--- 25/drivers/dlm/dlm_internal.h~dlm-lockspaces-callbacks-directory-dlm-consistent-ifdefs	Thu Jun  2 16:37:47 2005
+++ 25-akpm/drivers/dlm/dlm_internal.h	Thu Jun  2 16:37:47 2005
@@ -80,14 +80,6 @@ struct dlm_mhandle;
 #define log_error(ls, fmt, args...) \
 	printk(KERN_ERR "dlm: %s: " fmt "\n", (ls)->ls_name, ##args)
 
-#ifdef CONFIG_DLM_DEBUG
-int dlm_create_debug_file(struct dlm_ls *ls);
-void dlm_delete_debug_file(struct dlm_ls *ls);
-#else
-static inline int dlm_create_debug_file(struct dlm_ls *ls) { return 0; }
-static inline void dlm_delete_debug_file(struct dlm_ls *ls) { }
-#endif
-
 #ifdef DLM_LOG_DEBUG
 #define log_debug(ls, fmt, args...) log_error(ls, fmt, ##args)
 #else
diff -puN drivers/dlm/lockspace.c~dlm-lockspaces-callbacks-directory-dlm-consistent-ifdefs drivers/dlm/lockspace.c
--- 25/drivers/dlm/lockspace.c~dlm-lockspaces-callbacks-directory-dlm-consistent-ifdefs	Thu Jun  2 16:37:47 2005
+++ 25-akpm/drivers/dlm/lockspace.c	Thu Jun  2 16:37:47 2005
@@ -23,6 +23,14 @@
 #include "memory.h"
 #include "lock.h"
 
+#ifdef CONFIG_DLM_DEBUG
+int dlm_create_debug_file(struct dlm_ls *ls);
+void dlm_delete_debug_file(struct dlm_ls *ls);
+#else
+static inline int dlm_create_debug_file(struct dlm_ls *ls) { return 0; }
+static inline void dlm_delete_debug_file(struct dlm_ls *ls) { }
+#endif
+
 static int			ls_count;
 static struct semaphore		ls_lock;
 static struct list_head		lslist;
_
